CompositionFailureCode

Enum CompositionFailureCode 

pub enum CompositionFailureCode {
Show 22 variants ProviderHttpStatus, ProviderTimeout, ProviderTransport, ProviderResponseTooLarge, ProviderMalformedJson, ProviderInvalidUtf8, ProviderSchemaError, CompositionInvalid, StaleContext, UnsupportedCapability, UnknownHandle, MissingRequiredAuthority, AdmissionFailed, LiveWorkspaceChanged, LiveSourceChanged, LiveRouteMissing, LivePolicyChanged, LiveDurableStateChanged, SourceUnresolved, SourceAmbiguous, InvalidActionSource, AuditFailure,
}
Stable, bounded failure classes used by durable composition audit events. These values are deliberately independent of provider diagnostics and may be safely retained without exposing prompts, model text, credentials, tool arguments, or response bodies.

Variants



ProviderHttpStatus



ProviderTimeout



ProviderTransport



ProviderResponseTooLarge



ProviderMalformedJson



ProviderInvalidUtf8



ProviderSchemaError



CompositionInvalid



StaleContext



UnsupportedCapability



UnknownHandle



MissingRequiredAuthority



AdmissionFailed



LiveWorkspaceChanged



LiveSourceChanged



LiveRouteMissing



LivePolicyChanged



LiveDurableStateChanged



SourceUnresolved



SourceAmbiguous



InvalidActionSource



AuditFailure

Implementations

Source

impl CompositionFailureCode

pub const fn as_str(self) -> &'static str