pub struct AdmittedComposedSurface { /* private fields */ }Expand description
A composition that has crossed the durable negotiated-renderer gate.
Implementations
Sourceimpl AdmittedComposedSurface
impl AdmittedComposedSurface
pub fn surface(&self) -> &Surface
pub fn rendered(&self) -> &str
pub fn context_digest(&self) -> &str
Sourcepub fn validate_for_execution(
&self,
context: &CompositionContext,
catalog: &ActionCatalog,
store: &EventStore,
) -> Result<(), CompositionError>
pub fn validate_for_execution( &self, context: &CompositionContext, catalog: &ActionCatalog, store: &EventStore, ) -> Result<(), CompositionError>
Cached presentation is historical, but executable selection is always fenced by the live host context, catalog binding, and durable state.