#[non_exhaustive]pub struct NativeField { /* private fields */ }Expand description
A value carries its source class all the way to the renderer. Values emitted by the projector are created by validated view builders.
Implementations