pub struct ServerManager { /* private fields */ }Implementations
Sourceimpl ServerManager
impl ServerManager
pub const fn new() -> Self
Sourcepub fn ensure_running(
&mut self,
config: ServerLaunchConfig,
) -> Result<ManagedServerEndpoint, ServerError>
pub fn ensure_running( &mut self, config: ServerLaunchConfig, ) -> Result<ManagedServerEndpoint, ServerError>
Reuse is limited to a still-live process this manager created with the exact same config. An unrelated listener is never adopted, even if it answers the health endpoint.
pub fn shutdown(&mut self) -> Result<(), ServerError>
pub fn diagnostics(&self) -> String